@@ -431,7 +431,6 @@ def verify_signature(fname, system_gpg=False):
             keys = []
             keys_path = os.path.join(td, 'keys')
             os.mkdir(keys_path)
-            print("XXX", pkg_resources.resource_listdir('carml', 'keys'))
             for k in pkg_resources.resource_listdir('carml', 'keys'):
                 if k.endswith('.asc'):
                     keys.append(pkg_resources.resource_filename('carml', os.path.join('keys', k)))
@@ -440,7 +439,6 @@ def verify_signature(fname, system_gpg=False):
                 raise RuntimeError('Internal error: failed to find shipped keys.')
 
             try:
-                print("DING", td, keys)
                 if subprocess.check_call(['gpg', '--quiet', '--homedir', td, '--import'] + keys):
                     raise RuntimeError("Key import failed.")
             except IOError:
